#!/bin/bash

amber18=$(module list 2>&1 | grep 'amber/18' -c)
amber16=$(module list 2>&1 | grep 'amber/16' -c)

if [ "$amber18" != "1" ] || [ "$amber16" != "0" ]; then
  echo "There is an issue with your Amber Modules environment! Quitting..."
  exit 1;
fi

# Run minimization steps
mpirun -np 8 $AMBERHOME/bin/pmemd.MPI -O -i S01-Min01-Proton.in        -o S01-Min01.out -p NLSYQ.prmtop -ref NLSYQ.inpcrd -c NLSYQ.inpcrd -r S01-Min01.rst
mpirun -np 8 $AMBERHOME/bin/pmemd.MPI -O -i S02-Min02-Solvent.in       -o S02-Min02.out -p NLSYQ.prmtop -ref NLSYQ.inpcrd -c S01-Min01.rst  -r S02-Min02.rst
mpirun -np 8 $AMBERHOME/bin/pmemd.MPI -O -i S03-Min03-Focused.in       -o S03-Min03.out -p NLSYQ.prmtop -ref NLSYQ.inpcrd -c S02-Min02.rst  -r S03-Min03.rst
mpirun -np 8 $AMBERHOME/bin/pmemd.MPI -O -i S04-Min04-Sidechains.in    -o S04-Min04.out -p NLSYQ.prmtop -ref NLSYQ.inpcrd -c S03-Min03.rst  -r S04-Min04.rst
mpirun -np 8 $AMBERHOME/bin/pmemd.MPI -O -i S05-Min05-All.in           -o S05-Min05.out -p NLSYQ.prmtop -ref NLSYQ.inpcrd -c S04-Min04.rst  -r S05-Min05.rst

# Run heating steps
mpirun -np 8 $AMBERHOME/bin/pmemd.MPI -O -i S06-Eql01-Heating-NTV.in   -o S06-Eql01.out -p NLSYQ.prmtop -c S05-Min05.rst -r S06-Eql01.rst -ref S05-Min05.rst -x S06-Eql01.nc
mpirun -np 8 $AMBERHOME/bin/pmemd.MPI -O -i S07-Eql02-Heating-NTP.in   -o S07-Eql02.out -p NLSYQ.prmtop -c S06-Eql01.rst -r S07-Eql02.rst -ref S06-Eql01.rst -x S07-Eql02.nc

# Run equilibration steps
$AMBERHOME/bin/pmemd.cuda -O -i S08-Eql03-EqlOnlyStage01.in -o S08-Eql03.out -p NLSYQ.prmtop -c S07-Eql02.rst -r S08-Eql03.rst -ref S07-Eql02.rst -x S08-Eql03.nc
$AMBERHOME/bin/pmemd.cuda -O -i S09-Eql04-EqlOnlyStage02.in -o S09-Eql04.out -p NLSYQ.prmtop -c S08-Eql03.rst -r S09-Eql04.rst -ref S08-Eql03.rst -x S09-Eql04.nc

# Run production
$AMBERHOME/bin/pmemd.cuda -O -i S10-Pro01-MD.in -o NLSYQ-Pro01.out -p NLSYQ.prmtop -c S09-Eql04.rst -r NLSYQ-Pro01.rst -ref S09-Eql04.rst -x NLSYQ-Pro01.nc
